#include <stdint.h>
#include <stdbool.h>

#define D(STRUCT_NAME) \
    typedef struct     \
    {                  \
    } STRUCT_NAME##_BLOB;

D(Ptr);
D(MaybePtr);
D(StringPtr);
D(MaybeStringPtr);
D(SharedByteList);
D(Byte);
D(ByteList);
D(Token);
D(TokenList);
D(Node);
D(NodeList);
D(Diagnostic);
D(DiagnosticList);
D(Comment);
D(CommentList);
D(MagicComment);
D(MagicCommentList);
D(SourceLine);
D(SourceLineList);
D(Bytes);
D(Loc);
D(MaybeLoc);
D(CommentType);
D(MagicCommentKind);
D(ErrorLevel);
D(DiagnosticMessage);
D(InputError);
D(DecoderResult);
D(Decoder);
D(RewriteAction);
D(LexStateAction);
D(TokenRewriterResult);
D(TokenRewriter);
D(MaybeDecoder);
D(MaybeTokenRewriter);
D(ParserOptions);
D(DecodedInput);
D(ParserResult);

#include "message_stubs.h"
#include "node_stubs.h"
